# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['LogsRoleArgs', 'LogsRole']

@pulumi.input_type
class LogsRoleArgs:
    def __init__(__self__, *,
                 description: pulumi.Input[builtins.str],
                 service_name: pulumi.Input[builtins.str],
                 name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a LogsRole resource.
        :param pulumi.Input[builtins.str] description: The role description
        :param pulumi.Input[builtins.str] service_name: The service name
        :param pulumi.Input[builtins.str] name: The role name
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "service_name", service_name)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Input[builtins.str]:
        """
        The role description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The role name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _LogsRoleState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 nb_member: Optional[pulumi.Input[builtins.int]] = None,
                 nb_permission: Optional[pulumi.Input[builtins.int]] = None,
                 role_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering LogsRole resources.
        :param pulumi.Input[builtins.str] created_at: Role creation date
        :param pulumi.Input[builtins.str] description: The role description
        :param pulumi.Input[builtins.str] name: The role name
        :param pulumi.Input[builtins.int] nb_member: number of member for the role
        :param pulumi.Input[builtins.int] nb_permission: number of configured permission for the role
        :param pulumi.Input[builtins.str] role_id: Role identifier
        :param pulumi.Input[builtins.str] service_name: The service name
        :param pulumi.Input[builtins.str] updated_at: Role last update date
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if nb_member is not None:
            pulumi.set(__self__, "nb_member", nb_member)
        if nb_permission is not None:
            pulumi.set(__self__, "nb_permission", nb_permission)
        if role_id is not None:
            pulumi.set(__self__, "role_id", role_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Role creation date
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The role description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The role name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="nbMember")
    def nb_member(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        number of member for the role
        """
        return pulumi.get(self, "nb_member")

    @nb_member.setter
    def nb_member(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "nb_member", value)

    @property
    @pulumi.getter(name="nbPermission")
    def nb_permission(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        number of configured permission for the role
        """
        return pulumi.get(self, "nb_permission")

    @nb_permission.setter
    def nb_permission(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "nb_permission", value)

    @property
    @pulumi.getter(name="roleId")
    def role_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Role identifier
        """
        return pulumi.get(self, "role_id")

    @role_id.setter
    def role_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "role_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Role last update date
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_at", value)


@pulumi.type_token("ovh:Dbaas/logsRole:LogsRole")
class LogsRole(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Reference a DBaaS logs role.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        ro = ovh.dbaas.LogsRole("ro",
            service_name="ldp-xx-xxxxx",
            name="Devops - RO",
            description="Devops - RO")
        ```

        ## Import

        OVHcloud DBaaS Log Role can be imported using the `service_name` and `role_id` of the role, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:Dbaas/logsRole:LogsRole  ovh_dbaas_logs_role.ro ldp-ra-XX/dc145bc2-eb01-4efe-a802-XXXXXX
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: The role description
        :param pulumi.Input[builtins.str] name: The role name
        :param pulumi.Input[builtins.str] service_name: The service name
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LogsRoleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Reference a DBaaS logs role.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        ro = ovh.dbaas.LogsRole("ro",
            service_name="ldp-xx-xxxxx",
            name="Devops - RO",
            description="Devops - RO")
        ```

        ## Import

        OVHcloud DBaaS Log Role can be imported using the `service_name` and `role_id` of the role, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:Dbaas/logsRole:LogsRole  ovh_dbaas_logs_role.ro ldp-ra-XX/dc145bc2-eb01-4efe-a802-XXXXXX
        ```

        :param str resource_name: The name of the resource.
        :param LogsRoleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LogsRoleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LogsRoleArgs.__new__(LogsRoleArgs)

            if description is None and not opts.urn:
                raise TypeError("Missing required property 'description'")
            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["created_at"] = None
            __props__.__dict__["nb_member"] = None
            __props__.__dict__["nb_permission"] = None
            __props__.__dict__["role_id"] = None
            __props__.__dict__["updated_at"] = None
        super(LogsRole, __self__).__init__(
            'ovh:Dbaas/logsRole:LogsRole',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            nb_member: Optional[pulumi.Input[builtins.int]] = None,
            nb_permission: Optional[pulumi.Input[builtins.int]] = None,
            role_id: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            updated_at: Optional[pulumi.Input[builtins.str]] = None) -> 'LogsRole':
        """
        Get an existing LogsRole resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] created_at: Role creation date
        :param pulumi.Input[builtins.str] description: The role description
        :param pulumi.Input[builtins.str] name: The role name
        :param pulumi.Input[builtins.int] nb_member: number of member for the role
        :param pulumi.Input[builtins.int] nb_permission: number of configured permission for the role
        :param pulumi.Input[builtins.str] role_id: Role identifier
        :param pulumi.Input[builtins.str] service_name: The service name
        :param pulumi.Input[builtins.str] updated_at: Role last update date
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LogsRoleState.__new__(_LogsRoleState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["nb_member"] = nb_member
        __props__.__dict__["nb_permission"] = nb_permission
        __props__.__dict__["role_id"] = role_id
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["updated_at"] = updated_at
        return LogsRole(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        Role creation date
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        The role description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The role name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nbMember")
    def nb_member(self) -> pulumi.Output[builtins.int]:
        """
        number of member for the role
        """
        return pulumi.get(self, "nb_member")

    @property
    @pulumi.getter(name="nbPermission")
    def nb_permission(self) -> pulumi.Output[builtins.int]:
        """
        number of configured permission for the role
        """
        return pulumi.get(self, "nb_permission")

    @property
    @pulumi.getter(name="roleId")
    def role_id(self) -> pulumi.Output[builtins.str]:
        """
        Role identifier
        """
        return pulumi.get(self, "role_id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The service name
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[builtins.str]:
        """
        Role last update date
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ResourceGroupArgs', 'ResourceGroup']

@pulumi.input_type
class ResourceGroupArgs:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a ResourceGroup resource.
        :param pulumi.Input[builtins.str] name: Name of the resource group
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] resources: Set of the URNs of the resources contained in the resource group. All urns must be ones of valid resources
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if resources is not None:
            pulumi.set(__self__, "resources", resources)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of the resource group
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def resources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Set of the URNs of the resources contained in the resource group. All urns must be ones of valid resources
        """
        return pulumi.get(self, "resources")

    @resources.setter
    def resources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "resources", value)


@pulumi.input_type
class _ResourceGroupState:
    def __init__(__self__, *,
                 group_urn: Optional[pulumi.Input[builtins.str]] = None,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 owner: Optional[pulumi.Input[builtins.str]] = None,
                 read_only: Optional[pulumi.Input[builtins.bool]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 updated_at: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ResourceGroup resources.
        :param pulumi.Input[builtins.str] group_urn: URN of the resource group, used when writing policies
        :param pulumi.Input[builtins.str] created_at: Date of the creation of the resource group
        :param pulumi.Input[builtins.str] name: Name of the resource group
        :param pulumi.Input[builtins.str] owner: Name of the account owning the resource group
        :param pulumi.Input[builtins.bool] read_only: Marks that the resource group is not editable. Usually means that this is a default resource group created by OVHcloud
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] resources: Set of the URNs of the resources contained in the resource group. All urns must be ones of valid resources
        :param pulumi.Input[builtins.str] updated_at: Date of the last modification of the resource group
        """
        if group_urn is not None:
            pulumi.set(__self__, "group_urn", group_urn)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if read_only is not None:
            pulumi.set(__self__, "read_only", read_only)
        if resources is not None:
            pulumi.set(__self__, "resources", resources)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="GroupURN")
    def group_urn(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        URN of the resource group, used when writing policies
        """
        return pulumi.get(self, "group_urn")

    @group_urn.setter
    def group_urn(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "group_urn", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Date of the creation of the resource group
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of the resource group
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of the account owning the resource group
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter(name="readOnly")
    def read_only(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Marks that the resource group is not editable. Usually means that this is a default resource group created by OVHcloud
        """
        return pulumi.get(self, "read_only")

    @read_only.setter
    def read_only(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "read_only", value)

    @property
    @pulumi.getter
    def resources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Set of the URNs of the resources contained in the resource group. All urns must be ones of valid resources
        """
        return pulumi.get(self, "resources")

    @resources.setter
    def resources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "resources", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Date of the last modification of the resource group
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_at", value)


@pulumi.type_token("ovh:Iam/resourceGroup:ResourceGroup")
class ResourceGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        Provides an OVHcloud IAM resource group.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        my_resource_group = ovh.iam.ResourceGroup("my_resource_group",
            name="my_resource_group",
            resources=[
                "urn:v1:eu:resource:service1:service1-id",
                "urn:v1:eu:resource:service2:service2-id",
            ])
        ```

        ## Import

        Resource groups can be imported by using their id.

        bash

        ```sh
        $ pulumi import ovh:Iam/resourceGroup:ResourceGroup my_resource_group resource_group_id
        ```

        -> Read only resource groups cannot be imported

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] name: Name of the resource group
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] resources: Set of the URNs of the resources contained in the resource group. All urns must be ones of valid resources
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ResourceGroupArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides an OVHcloud IAM resource group.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        my_resource_group = ovh.iam.ResourceGroup("my_resource_group",
            name="my_resource_group",
            resources=[
                "urn:v1:eu:resource:service1:service1-id",
                "urn:v1:eu:resource:service2:service2-id",
            ])
        ```

        ## Import

        Resource groups can be imported by using their id.

        bash

        ```sh
        $ pulumi import ovh:Iam/resourceGroup:ResourceGroup my_resource_group resource_group_id
        ```

        -> Read only resource groups cannot be imported

        :param str resource_name: The name of the resource.
        :param ResourceGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ResourceGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ResourceGroupArgs.__new__(ResourceGroupArgs)

            __props__.__dict__["name"] = name
            __props__.__dict__["resources"] = resources
            __props__.__dict__["group_urn"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["owner"] = None
            __props__.__dict__["read_only"] = None
            __props__.__dict__["updated_at"] = None
        super(ResourceGroup, __self__).__init__(
            'ovh:Iam/resourceGroup:ResourceGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            group_urn: Optional[pulumi.Input[builtins.str]] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            owner: Optional[pulumi.Input[builtins.str]] = None,
            read_only: Optional[pulumi.Input[builtins.bool]] = None,
            resources: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            updated_at: Optional[pulumi.Input[builtins.str]] = None) -> 'ResourceGroup':
        """
        Get an existing ResourceGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] group_urn: URN of the resource group, used when writing policies
        :param pulumi.Input[builtins.str] created_at: Date of the creation of the resource group
        :param pulumi.Input[builtins.str] name: Name of the resource group
        :param pulumi.Input[builtins.str] owner: Name of the account owning the resource group
        :param pulumi.Input[builtins.bool] read_only: Marks that the resource group is not editable. Usually means that this is a default resource group created by OVHcloud
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] resources: Set of the URNs of the resources contained in the resource group. All urns must be ones of valid resources
        :param pulumi.Input[builtins.str] updated_at: Date of the last modification of the resource group
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ResourceGroupState.__new__(_ResourceGroupState)

        __props__.__dict__["group_urn"] = group_urn
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["name"] = name
        __props__.__dict__["owner"] = owner
        __props__.__dict__["read_only"] = read_only
        __props__.__dict__["resources"] = resources
        __props__.__dict__["updated_at"] = updated_at
        return ResourceGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="GroupURN")
    def group_urn(self) -> pulumi.Output[builtins.str]:
        """
        URN of the resource group, used when writing policies
        """
        return pulumi.get(self, "group_urn")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        Date of the creation of the resource group
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Name of the resource group
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output[builtins.str]:
        """
        Name of the account owning the resource group
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="readOnly")
    def read_only(self) -> pulumi.Output[builtins.bool]:
        """
        Marks that the resource group is not editable. Usually means that this is a default resource group created by OVHcloud
        """
        return pulumi.get(self, "read_only")

    @property
    @pulumi.getter
    def resources(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        Set of the URNs of the resources contained in the resource group. All urns must be ones of valid resources
        """
        return pulumi.get(self, "resources")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[builtins.str]:
        """
        Date of the last modification of the resource group
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetDatabaseLogSubscriptionResult',
    'AwaitableGetDatabaseLogSubscriptionResult',
    'get_database_log_subscription',
    'get_database_log_subscription_output',
]

@pulumi.output_type
class GetDatabaseLogSubscriptionResult:
    """
    A collection of values returned by getDatabaseLogSubscription.
    """
    def __init__(__self__, cluster_id=None, created_at=None, engine=None, id=None, kind=None, ldp_service_name=None, resource_name=None, resource_type=None, service_name=None, stream_id=None, updated_at=None):
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        pulumi.set(__self__, "cluster_id", cluster_id)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if engine and not isinstance(engine, str):
            raise TypeError("Expected argument 'engine' to be a str")
        pulumi.set(__self__, "engine", engine)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if kind and not isinstance(kind, str):
            raise TypeError("Expected argument 'kind' to be a str")
        pulumi.set(__self__, "kind", kind)
        if ldp_service_name and not isinstance(ldp_service_name, str):
            raise TypeError("Expected argument 'ldp_service_name' to be a str")
        pulumi.set(__self__, "ldp_service_name", ldp_service_name)
        if resource_name and not isinstance(resource_name, str):
            raise TypeError("Expected argument 'resource_name' to be a str")
        pulumi.set(__self__, "resource_name", resource_name)
        if resource_type and not isinstance(resource_type, str):
            raise TypeError("Expected argument 'resource_type' to be a str")
        pulumi.set(__self__, "resource_type", resource_type)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if stream_id and not isinstance(stream_id, str):
            raise TypeError("Expected argument 'stream_id' to be a str")
        pulumi.set(__self__, "stream_id", stream_id)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> builtins.str:
        """
        Creation date of the subscription.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def engine(self) -> builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "engine")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        ID of the log subscription.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def kind(self) -> builtins.str:
        """
        Log kind name of this subscription.
        """
        return pulumi.get(self, "kind")

    @property
    @pulumi.getter(name="ldpServiceName")
    def ldp_service_name(self) -> builtins.str:
        """
        Name of the destination log service.
        """
        return pulumi.get(self, "ldp_service_name")

    @property
    @pulumi.getter(name="resourceName")
    def resource_name(self) -> builtins.str:
        """
        Name of subscribed resource, where the logs come from.
        """
        return pulumi.get(self, "resource_name")

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> builtins.str:
        """
        Type of subscribed resource, where the logs come from.
        """
        return pulumi.get(self, "resource_type")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="streamId")
    def stream_id(self) -> builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "stream_id")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> builtins.str:
        """
        Last update date of the subscription.
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetDatabaseLogSubscriptionResult(GetDatabaseLogSubscriptionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDatabaseLogSubscriptionResult(
            cluster_id=self.cluster_id,
            created_at=self.created_at,
            engine=self.engine,
            id=self.id,
            kind=self.kind,
            ldp_service_name=self.ldp_service_name,
            resource_name=self.resource_name,
            resource_type=self.resource_type,
            service_name=self.service_name,
            stream_id=self.stream_id,
            updated_at=self.updated_at)


def get_database_log_subscription(cluster_id: Optional[builtins.str] = None,
                                  engine: Optional[builtins.str] = None,
                                  id: Optional[builtins.str] = None,
                                  service_name: Optional[builtins.str] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDatabaseLogSubscriptionResult:
    """
    Use this data source to get information about a log subscription for a cluster associated with a public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    subscription = ovh.CloudProjectDatabase.get_database_log_subscription(service_name="VVV",
        engine="XXX",
        cluster_id="YYY",
        id="ZZZ")
    pulumi.export("subscriptionLdpName", subscription.ldp_service_name)
    ```


    :param builtins.str cluster_id: Cluster ID.
    :param builtins.str engine: The database engine for which you want to retrieve a subscription. To get a full list of available engine visit. [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
    :param builtins.str id: Id of the log subscription.
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['engine'] = engine
    __args__['id'] = id
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProjectDatabase/getDatabaseLogSubscription:getDatabaseLogSubscription', __args__, opts=opts, typ=GetDatabaseLogSubscriptionResult).value

    return AwaitableGetDatabaseLogSubscriptionResult(
        cluster_id=pulumi.get(__ret__, 'cluster_id'),
        created_at=pulumi.get(__ret__, 'created_at'),
        engine=pulumi.get(__ret__, 'engine'),
        id=pulumi.get(__ret__, 'id'),
        kind=pulumi.get(__ret__, 'kind'),
        ldp_service_name=pulumi.get(__ret__, 'ldp_service_name'),
        resource_name=pulumi.get(__ret__, 'resource_name'),
        resource_type=pulumi.get(__ret__, 'resource_type'),
        service_name=pulumi.get(__ret__, 'service_name'),
        stream_id=pulumi.get(__ret__, 'stream_id'),
        updated_at=pulumi.get(__ret__, 'updated_at'))
def get_database_log_subscription_output(cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                                         engine: Optional[pulumi.Input[builtins.str]] = None,
                                         id: Optional[pulumi.Input[builtins.str]] = None,
                                         service_name: Optional[pulumi.Input[builtins.str]] = None,
                                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDatabaseLogSubscriptionResult]:
    """
    Use this data source to get information about a log subscription for a cluster associated with a public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    subscription = ovh.CloudProjectDatabase.get_database_log_subscription(service_name="VVV",
        engine="XXX",
        cluster_id="YYY",
        id="ZZZ")
    pulumi.export("subscriptionLdpName", subscription.ldp_service_name)
    ```


    :param builtins.str cluster_id: Cluster ID.
    :param builtins.str engine: The database engine for which you want to retrieve a subscription. To get a full list of available engine visit. [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
    :param builtins.str id: Id of the log subscription.
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['engine'] = engine
    __args__['id'] = id
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProjectDatabase/getDatabaseLogSubscription:getDatabaseLogSubscription', __args__, opts=opts, typ=GetDatabaseLogSubscriptionResult)
    return __ret__.apply(lambda __response__: GetDatabaseLogSubscriptionResult(
        cluster_id=pulumi.get(__response__, 'cluster_id'),
        created_at=pulumi.get(__response__, 'created_at'),
        engine=pulumi.get(__response__, 'engine'),
        id=pulumi.get(__response__, 'id'),
        kind=pulumi.get(__response__, 'kind'),
        ldp_service_name=pulumi.get(__response__, 'ldp_service_name'),
        resource_name=pulumi.get(__response__, 'resource_name'),
        resource_type=pulumi.get(__response__, 'resource_type'),
        service_name=pulumi.get(__response__, 'service_name'),
        stream_id=pulumi.get(__response__, 'stream_id'),
        updated_at=pulumi.get(__response__, 'updated_at')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NameServersArgs', 'NameServers']

@pulumi.input_type
class NameServersArgs:
    def __init__(__self__, *,
                 domain: pulumi.Input[builtins.str],
                 servers: pulumi.Input[Sequence[pulumi.Input['NameServersServerArgs']]]):
        """
        The set of arguments for constructing a NameServers resource.
        :param pulumi.Input[builtins.str] domain: Domain name for which to manage name servers
        :param pulumi.Input[Sequence[pulumi.Input['NameServersServerArgs']]] servers: Details about a name server
        """
        pulumi.set(__self__, "domain", domain)
        pulumi.set(__self__, "servers", servers)

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Input[builtins.str]:
        """
        Domain name for which to manage name servers
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter
    def servers(self) -> pulumi.Input[Sequence[pulumi.Input['NameServersServerArgs']]]:
        """
        Details about a name server
        """
        return pulumi.get(self, "servers")

    @servers.setter
    def servers(self, value: pulumi.Input[Sequence[pulumi.Input['NameServersServerArgs']]]):
        pulumi.set(self, "servers", value)


@pulumi.input_type
class _NameServersState:
    def __init__(__self__, *,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 servers: Optional[pulumi.Input[Sequence[pulumi.Input['NameServersServerArgs']]]] = None):
        """
        Input properties used for looking up and filtering NameServers resources.
        :param pulumi.Input[builtins.str] domain: Domain name for which to manage name servers
        :param pulumi.Input[Sequence[pulumi.Input['NameServersServerArgs']]] servers: Details about a name server
        """
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if servers is not None:
            pulumi.set(__self__, "servers", servers)

    @property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Domain name for which to manage name servers
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter
    def servers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NameServersServerArgs']]]]:
        """
        Details about a name server
        """
        return pulumi.get(self, "servers")

    @servers.setter
    def servers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NameServersServerArgs']]]]):
        pulumi.set(self, "servers", value)


@pulumi.type_token("ovh:Domain/nameServers:NameServers")
class NameServers(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 servers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NameServersServerArgs', 'NameServersServerArgsDict']]]]] = None,
                 __props__=None):
        """
        Use this resource to manage a domain's name servers.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        name_servers = ovh.domain.NameServers("name_servers",
            domain="mydomain.ovh",
            servers=[
                {
                    "host": "dns105.ovh.net",
                    "ip": "213.251.188.144",
                },
                {
                    "host": "ns105.ovh.net",
                },
            ])
        ```

        ## Import

        Name servers can be imported using their `domain`.

        Using the following configuration:

        terraform

        import {

          to = ovh_domain_name_servers.name_servers

          id = "<domain name>"

        }

        You can then run:

        bash

        $ pulumi preview -generate-config-out=name_servers.tf

        $ pulumi up

        The file `name_servers.tf` will then contain the imported resource's configuration, that can be copied next to the `import` block above. See https://developer.hashicorp.com/terraform/language/import/generating-configuration for more details.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] domain: Domain name for which to manage name servers
        :param pulumi.Input[Sequence[pulumi.Input[Union['NameServersServerArgs', 'NameServersServerArgsDict']]]] servers: Details about a name server
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NameServersArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Use this resource to manage a domain's name servers.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        name_servers = ovh.domain.NameServers("name_servers",
            domain="mydomain.ovh",
            servers=[
                {
                    "host": "dns105.ovh.net",
                    "ip": "213.251.188.144",
                },
                {
                    "host": "ns105.ovh.net",
                },
            ])
        ```

        ## Import

        Name servers can be imported using their `domain`.

        Using the following configuration:

        terraform

        import {

          to = ovh_domain_name_servers.name_servers

          id = "<domain name>"

        }

        You can then run:

        bash

        $ pulumi preview -generate-config-out=name_servers.tf

        $ pulumi up

        The file `name_servers.tf` will then contain the imported resource's configuration, that can be copied next to the `import` block above. See https://developer.hashicorp.com/terraform/language/import/generating-configuration for more details.

        :param str resource_name: The name of the resource.
        :param NameServersArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NameServersArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 servers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NameServersServerArgs', 'NameServersServerArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NameServersArgs.__new__(NameServersArgs)

            if domain is None and not opts.urn:
                raise TypeError("Missing required property 'domain'")
            __props__.__dict__["domain"] = domain
            if servers is None and not opts.urn:
                raise TypeError("Missing required property 'servers'")
            __props__.__dict__["servers"] = servers
        super(NameServers, __self__).__init__(
            'ovh:Domain/nameServers:NameServers',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            domain: Optional[pulumi.Input[builtins.str]] = None,
            servers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NameServersServerArgs', 'NameServersServerArgsDict']]]]] = None) -> 'NameServers':
        """
        Get an existing NameServers resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] domain: Domain name for which to manage name servers
        :param pulumi.Input[Sequence[pulumi.Input[Union['NameServersServerArgs', 'NameServersServerArgsDict']]]] servers: Details about a name server
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NameServersState.__new__(_NameServersState)

        __props__.__dict__["domain"] = domain
        __props__.__dict__["servers"] = servers
        return NameServers(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Output[builtins.str]:
        """
        Domain name for which to manage name servers
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter
    def servers(self) -> pulumi.Output[Sequence['outputs.NameServersServer']]:
        """
        Details about a name server
        """
        return pulumi.get(self, "servers")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetOvhcloudConnectDatacentersResult',
    'AwaitableGetOvhcloudConnectDatacentersResult',
    'get_ovhcloud_connect_datacenters',
    'get_ovhcloud_connect_datacenters_output',
]

@pulumi.output_type
class GetOvhcloudConnectDatacentersResult:
    """
    A collection of values returned by getOvhcloudConnectDatacenters.
    """
    def __init__(__self__, datacenters=None, id=None, service_name=None):
        if datacenters and not isinstance(datacenters, list):
            raise TypeError("Expected argument 'datacenters' to be a list")
        pulumi.set(__self__, "datacenters", datacenters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter
    def datacenters(self) -> Sequence['outputs.GetOvhcloudConnectDatacentersDatacenterResult']:
        return pulumi.get(self, "datacenters")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        """
        Service name
        """
        return pulumi.get(self, "service_name")


class AwaitableGetOvhcloudConnectDatacentersResult(GetOvhcloudConnectDatacentersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetOvhcloudConnectDatacentersResult(
            datacenters=self.datacenters,
            id=self.id,
            service_name=self.service_name)


def get_ovhcloud_connect_datacenters(service_name: Optional[builtins.str] = None,
                                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetOvhcloudConnectDatacentersResult:
    """
    Use this data source to retrieve information about Datacenters for an Ovhcloud Connect product.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    dcs = ovh.get_ovhcloud_connect_datacenters(service_name="XXX")
    ```


    :param builtins.str service_name: Service name
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:index/getOvhcloudConnectDatacenters:getOvhcloudConnectDatacenters', __args__, opts=opts, typ=GetOvhcloudConnectDatacentersResult).value

    return AwaitableGetOvhcloudConnectDatacentersResult(
        datacenters=pulumi.get(__ret__, 'datacenters'),
        id=pulumi.get(__ret__, 'id'),
        service_name=pulumi.get(__ret__, 'service_name'))
def get_ovhcloud_connect_datacenters_output(service_name: Optional[pulumi.Input[builtins.str]] = None,
                                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetOvhcloudConnectDatacentersResult]:
    """
    Use this data source to retrieve information about Datacenters for an Ovhcloud Connect product.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    dcs = ovh.get_ovhcloud_connect_datacenters(service_name="XXX")
    ```


    :param builtins.str service_name: Service name
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:index/getOvhcloudConnectDatacenters:getOvhcloudConnectDatacenters', __args__, opts=opts, typ=GetOvhcloudConnectDatacentersResult)
    return __ret__.apply(lambda __response__: GetOvhcloudConnectDatacentersResult(
        datacenters=pulumi.get(__response__, 'datacenters'),
        id=pulumi.get(__response__, 'id'),
        service_name=pulumi.get(__response__, 'service_name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetServerResult',
    'AwaitableGetServerResult',
    'get_server',
    'get_server_output',
]

@pulumi.output_type
class GetServerResult:
    """
    A collection of values returned by getServer.
    """
    def __init__(__self__, server_urn=None, availability_zone=None, boot_id=None, boot_script=None, commercial_range=None, datacenter=None, display_name=None, efi_bootloader_path=None, enabled_public_vnis=None, enabled_vrack_aggregation_vnis=None, enabled_vrack_vnis=None, id=None, ip=None, ips=None, link_speed=None, monitoring=None, name=None, new_upgrade_system=None, no_intervention=None, os=None, power_state=None, professional_use=None, rack=None, region=None, rescue_mail=None, rescue_ssh_key=None, reverse=None, root_device=None, server_id=None, service_name=None, state=None, support_level=None, vnis=None):
        if server_urn and not isinstance(server_urn, str):
            raise TypeError("Expected argument 'server_urn' to be a str")
        pulumi.set(__self__, "server_urn", server_urn)
        if availability_zone and not isinstance(availability_zone, str):
            raise TypeError("Expected argument 'availability_zone' to be a str")
        pulumi.set(__self__, "availability_zone", availability_zone)
        if boot_id and not isinstance(boot_id, int):
            raise TypeError("Expected argument 'boot_id' to be a int")
        pulumi.set(__self__, "boot_id", boot_id)
        if boot_script and not isinstance(boot_script, str):
            raise TypeError("Expected argument 'boot_script' to be a str")
        pulumi.set(__self__, "boot_script", boot_script)
        if commercial_range and not isinstance(commercial_range, str):
            raise TypeError("Expected argument 'commercial_range' to be a str")
        pulumi.set(__self__, "commercial_range", commercial_range)
        if datacenter and not isinstance(datacenter, str):
            raise TypeError("Expected argument 'datacenter' to be a str")
        pulumi.set(__self__, "datacenter", datacenter)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if efi_bootloader_path and not isinstance(efi_bootloader_path, str):
            raise TypeError("Expected argument 'efi_bootloader_path' to be a str")
        pulumi.set(__self__, "efi_bootloader_path", efi_bootloader_path)
        if enabled_public_vnis and not isinstance(enabled_public_vnis, list):
            raise TypeError("Expected argument 'enabled_public_vnis' to be a list")
        pulumi.set(__self__, "enabled_public_vnis", enabled_public_vnis)
        if enabled_vrack_aggregation_vnis and not isinstance(enabled_vrack_aggregation_vnis, list):
            raise TypeError("Expected argument 'enabled_vrack_aggregation_vnis' to be a list")
        pulumi.set(__self__, "enabled_vrack_aggregation_vnis", enabled_vrack_aggregation_vnis)
        if enabled_vrack_vnis and not isinstance(enabled_vrack_vnis, list):
            raise TypeError("Expected argument 'enabled_vrack_vnis' to be a list")
        pulumi.set(__self__, "enabled_vrack_vnis", enabled_vrack_vnis)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ip and not isinstance(ip, str):
            raise TypeError("Expected argument 'ip' to be a str")
        pulumi.set(__self__, "ip", ip)
        if ips and not isinstance(ips, list):
            raise TypeError("Expected argument 'ips' to be a list")
        pulumi.set(__self__, "ips", ips)
        if link_speed and not isinstance(link_speed, int):
            raise TypeError("Expected argument 'link_speed' to be a int")
        pulumi.set(__self__, "link_speed", link_speed)
        if monitoring and not isinstance(monitoring, bool):
            raise TypeError("Expected argument 'monitoring' to be a bool")
        pulumi.set(__self__, "monitoring", monitoring)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if new_upgrade_system and not isinstance(new_upgrade_system, bool):
            raise TypeError("Expected argument 'new_upgrade_system' to be a bool")
        pulumi.set(__self__, "new_upgrade_system", new_upgrade_system)
        if no_intervention and not isinstance(no_intervention, bool):
            raise TypeError("Expected argument 'no_intervention' to be a bool")
        pulumi.set(__self__, "no_intervention", no_intervention)
        if os and not isinstance(os, str):
            raise TypeError("Expected argument 'os' to be a str")
        pulumi.set(__self__, "os", os)
        if power_state and not isinstance(power_state, str):
            raise TypeError("Expected argument 'power_state' to be a str")
        pulumi.set(__self__, "power_state", power_state)
        if professional_use and not isinstance(professional_use, bool):
            raise TypeError("Expected argument 'professional_use' to be a bool")
        pulumi.set(__self__, "professional_use", professional_use)
        if rack and not isinstance(rack, str):
            raise TypeError("Expected argument 'rack' to be a str")
        pulumi.set(__self__, "rack", rack)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if rescue_mail and not isinstance(rescue_mail, str):
            raise TypeError("Expected argument 'rescue_mail' to be a str")
        pulumi.set(__self__, "rescue_mail", rescue_mail)
        if rescue_ssh_key and not isinstance(rescue_ssh_key, str):
            raise TypeError("Expected argument 'rescue_ssh_key' to be a str")
        pulumi.set(__self__, "rescue_ssh_key", rescue_ssh_key)
        if reverse and not isinstance(reverse, str):
            raise TypeError("Expected argument 'reverse' to be a str")
        pulumi.set(__self__, "reverse", reverse)
        if root_device and not isinstance(root_device, str):
            raise TypeError("Expected argument 'root_device' to be a str")
        pulumi.set(__self__, "root_device", root_device)
        if server_id and not isinstance(server_id, int):
            raise TypeError("Expected argument 'server_id' to be a int")
        pulumi.set(__self__, "server_id", server_id)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if support_level and not isinstance(support_level, str):
            raise TypeError("Expected argument 'support_level' to be a str")
        pulumi.set(__self__, "support_level", support_level)
        if vnis and not isinstance(vnis, list):
            raise TypeError("Expected argument 'vnis' to be a list")
        pulumi.set(__self__, "vnis", vnis)

    @property
    @pulumi.getter(name="ServerURN")
    def server_urn(self) -> builtins.str:
        """
        URN of the dedicated server instance
        """
        return pulumi.get(self, "server_urn")

    @property
    @pulumi.getter(name="availabilityZone")
    def availability_zone(self) -> builtins.str:
        """
        Dedicated AZ localisation
        """
        return pulumi.get(self, "availability_zone")

    @property
    @pulumi.getter(name="bootId")
    def boot_id(self) -> builtins.int:
        """
        Boot id of the server
        """
        return pulumi.get(self, "boot_id")

    @property
    @pulumi.getter(name="bootScript")
    def boot_script(self) -> builtins.str:
        """
        Boot script of the server
        """
        return pulumi.get(self, "boot_script")

    @property
    @pulumi.getter(name="commercialRange")
    def commercial_range(self) -> builtins.str:
        """
        Dedicated server commercial range
        """
        return pulumi.get(self, "commercial_range")

    @property
    @pulumi.getter
    def datacenter(self) -> builtins.str:
        """
        Dedicated datacenter localisation (bhs1,bhs2,...)
        """
        return pulumi.get(self, "datacenter")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> builtins.str:
        """
        Dedicated server display name
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="efiBootloaderPath")
    def efi_bootloader_path(self) -> builtins.str:
        """
        Path of the EFI bootloader of the dedicated server
        """
        return pulumi.get(self, "efi_bootloader_path")

    @property
    @pulumi.getter(name="enabledPublicVnis")
    def enabled_public_vnis(self) -> Sequence[builtins.str]:
        """
        List of enabled public VNI uuids
        """
        return pulumi.get(self, "enabled_public_vnis")

    @property
    @pulumi.getter(name="enabledVrackAggregationVnis")
    def enabled_vrack_aggregation_vnis(self) -> Sequence[builtins.str]:
        """
        List of enabled vrack_aggregation VNI uuids
        """
        return pulumi.get(self, "enabled_vrack_aggregation_vnis")

    @property
    @pulumi.getter(name="enabledVrackVnis")
    def enabled_vrack_vnis(self) -> Sequence[builtins.str]:
        """
        List of enabled vrack VNI uuids
        """
        return pulumi.get(self, "enabled_vrack_vnis")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ip(self) -> builtins.str:
        """
        Dedicated server ip (IPv4)
        """
        return pulumi.get(self, "ip")

    @property
    @pulumi.getter
    def ips(self) -> Sequence[builtins.str]:
        """
        Dedicated server ip blocks
        """
        return pulumi.get(self, "ips")

    @property
    @pulumi.getter(name="linkSpeed")
    def link_speed(self) -> builtins.int:
        """
        Link speed of the server
        """
        return pulumi.get(self, "link_speed")

    @property
    @pulumi.getter
    def monitoring(self) -> builtins.bool:
        """
        Icmp monitoring state
        """
        return pulumi.get(self, "monitoring")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        User defined VirtualNetworkInterface name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="newUpgradeSystem")
    def new_upgrade_system(self) -> builtins.bool:
        return pulumi.get(self, "new_upgrade_system")

    @property
    @pulumi.getter(name="noIntervention")
    def no_intervention(self) -> builtins.bool:
        """
        Prevent datacenter intervention
        """
        return pulumi.get(self, "no_intervention")

    @property
    @pulumi.getter
    def os(self) -> builtins.str:
        """
        Operating system
        """
        return pulumi.get(self, "os")

    @property
    @pulumi.getter(name="powerState")
    def power_state(self) -> builtins.str:
        """
        Power state of the server (poweroff, poweron)
        """
        return pulumi.get(self, "power_state")

    @property
    @pulumi.getter(name="professionalUse")
    def professional_use(self) -> builtins.bool:
        """
        Does this server have professional use option
        """
        return pulumi.get(self, "professional_use")

    @property
    @pulumi.getter
    def rack(self) -> builtins.str:
        """
        Rack id of the server
        """
        return pulumi.get(self, "rack")

    @property
    @pulumi.getter
    def region(self) -> builtins.str:
        """
        Dedicated region localisation
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="rescueMail")
    def rescue_mail(self) -> builtins.str:
        """
        Rescue mail of the server
        """
        return pulumi.get(self, "rescue_mail")

    @property
    @pulumi.getter(name="rescueSshKey")
    def rescue_ssh_key(self) -> builtins.str:
        """
        Public SSH Key used in the rescue mode
        """
        return pulumi.get(self, "rescue_ssh_key")

    @property
    @pulumi.getter
    def reverse(self) -> builtins.str:
        """
        Dedicated server reverse
        """
        return pulumi.get(self, "reverse")

    @property
    @pulumi.getter(name="rootDevice")
    def root_device(self) -> builtins.str:
        """
        Root device of the server
        """
        return pulumi.get(self, "root_device")

    @property
    @pulumi.getter(name="serverId")
    def server_id(self) -> builtins.int:
        """
        Server id
        """
        return pulumi.get(self, "server_id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def state(self) -> builtins.str:
        """
        Error, hacked, hackedBlocked, ok
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="supportLevel")
    def support_level(self) -> builtins.str:
        """
        Dedicated server support level (critical, fastpath, gs, pro)
        """
        return pulumi.get(self, "support_level")

    @property
    @pulumi.getter
    def vnis(self) -> Sequence['outputs.GetServerVniResult']:
        """
        The list of Virtualnetworkinterface associated with this server
        """
        return pulumi.get(self, "vnis")


class AwaitableGetServerResult(GetServerResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetServerResult(
            server_urn=self.server_urn,
            availability_zone=self.availability_zone,
            boot_id=self.boot_id,
            boot_script=self.boot_script,
            commercial_range=self.commercial_range,
            datacenter=self.datacenter,
            display_name=self.display_name,
            efi_bootloader_path=self.efi_bootloader_path,
            enabled_public_vnis=self.enabled_public_vnis,
            enabled_vrack_aggregation_vnis=self.enabled_vrack_aggregation_vnis,
            enabled_vrack_vnis=self.enabled_vrack_vnis,
            id=self.id,
            ip=self.ip,
            ips=self.ips,
            link_speed=self.link_speed,
            monitoring=self.monitoring,
            name=self.name,
            new_upgrade_system=self.new_upgrade_system,
            no_intervention=self.no_intervention,
            os=self.os,
            power_state=self.power_state,
            professional_use=self.professional_use,
            rack=self.rack,
            region=self.region,
            rescue_mail=self.rescue_mail,
            rescue_ssh_key=self.rescue_ssh_key,
            reverse=self.reverse,
            root_device=self.root_device,
            server_id=self.server_id,
            service_name=self.service_name,
            state=self.state,
            support_level=self.support_level,
            vnis=self.vnis)


def get_server(service_name: Optional[builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetServerResult:
    """
    Use this data source to retrieve information about a dedicated server associated with your OVHcloud Account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    server = ovh.get_server(service_name="XXXXXX")
    ```


    :param builtins.str service_name: The service_name of your dedicated server.
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:index/getServer:getServer', __args__, opts=opts, typ=GetServerResult).value

    return AwaitableGetServerResult(
        server_urn=pulumi.get(__ret__, 'server_urn'),
        availability_zone=pulumi.get(__ret__, 'availability_zone'),
        boot_id=pulumi.get(__ret__, 'boot_id'),
        boot_script=pulumi.get(__ret__, 'boot_script'),
        commercial_range=pulumi.get(__ret__, 'commercial_range'),
        datacenter=pulumi.get(__ret__, 'datacenter'),
        display_name=pulumi.get(__ret__, 'display_name'),
        efi_bootloader_path=pulumi.get(__ret__, 'efi_bootloader_path'),
        enabled_public_vnis=pulumi.get(__ret__, 'enabled_public_vnis'),
        enabled_vrack_aggregation_vnis=pulumi.get(__ret__, 'enabled_vrack_aggregation_vnis'),
        enabled_vrack_vnis=pulumi.get(__ret__, 'enabled_vrack_vnis'),
        id=pulumi.get(__ret__, 'id'),
        ip=pulumi.get(__ret__, 'ip'),
        ips=pulumi.get(__ret__, 'ips'),
        link_speed=pulumi.get(__ret__, 'link_speed'),
        monitoring=pulumi.get(__ret__, 'monitoring'),
        name=pulumi.get(__ret__, 'name'),
        new_upgrade_system=pulumi.get(__ret__, 'new_upgrade_system'),
        no_intervention=pulumi.get(__ret__, 'no_intervention'),
        os=pulumi.get(__ret__, 'os'),
        power_state=pulumi.get(__ret__, 'power_state'),
        professional_use=pulumi.get(__ret__, 'professional_use'),
        rack=pulumi.get(__ret__, 'rack'),
        region=pulumi.get(__ret__, 'region'),
        rescue_mail=pulumi.get(__ret__, 'rescue_mail'),
        rescue_ssh_key=pulumi.get(__ret__, 'rescue_ssh_key'),
        reverse=pulumi.get(__ret__, 'reverse'),
        root_device=pulumi.get(__ret__, 'root_device'),
        server_id=pulumi.get(__ret__, 'server_id'),
        service_name=pulumi.get(__ret__, 'service_name'),
        state=pulumi.get(__ret__, 'state'),
        support_level=pulumi.get(__ret__, 'support_level'),
        vnis=pulumi.get(__ret__, 'vnis'))
def get_server_output(service_name: Optional[pulumi.Input[builtins.str]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetServerResult]:
    """
    Use this data source to retrieve information about a dedicated server associated with your OVHcloud Account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    server = ovh.get_server(service_name="XXXXXX")
    ```


    :param builtins.str service_name: The service_name of your dedicated server.
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:index/getServer:getServer', __args__, opts=opts, typ=GetServerResult)
    return __ret__.apply(lambda __response__: GetServerResult(
        server_urn=pulumi.get(__response__, 'server_urn'),
        availability_zone=pulumi.get(__response__, 'availability_zone'),
        boot_id=pulumi.get(__response__, 'boot_id'),
        boot_script=pulumi.get(__response__, 'boot_script'),
        commercial_range=pulumi.get(__response__, 'commercial_range'),
        datacenter=pulumi.get(__response__, 'datacenter'),
        display_name=pulumi.get(__response__, 'display_name'),
        efi_bootloader_path=pulumi.get(__response__, 'efi_bootloader_path'),
        enabled_public_vnis=pulumi.get(__response__, 'enabled_public_vnis'),
        enabled_vrack_aggregation_vnis=pulumi.get(__response__, 'enabled_vrack_aggregation_vnis'),
        enabled_vrack_vnis=pulumi.get(__response__, 'enabled_vrack_vnis'),
        id=pulumi.get(__response__, 'id'),
        ip=pulumi.get(__response__, 'ip'),
        ips=pulumi.get(__response__, 'ips'),
        link_speed=pulumi.get(__response__, 'link_speed'),
        monitoring=pulumi.get(__response__, 'monitoring'),
        name=pulumi.get(__response__, 'name'),
        new_upgrade_system=pulumi.get(__response__, 'new_upgrade_system'),
        no_intervention=pulumi.get(__response__, 'no_intervention'),
        os=pulumi.get(__response__, 'os'),
        power_state=pulumi.get(__response__, 'power_state'),
        professional_use=pulumi.get(__response__, 'professional_use'),
        rack=pulumi.get(__response__, 'rack'),
        region=pulumi.get(__response__, 'region'),
        rescue_mail=pulumi.get(__response__, 'rescue_mail'),
        rescue_ssh_key=pulumi.get(__response__, 'rescue_ssh_key'),
        reverse=pulumi.get(__response__, 'reverse'),
        root_device=pulumi.get(__response__, 'root_device'),
        server_id=pulumi.get(__response__, 'server_id'),
        service_name=pulumi.get(__response__, 'service_name'),
        state=pulumi.get(__response__, 'state'),
        support_level=pulumi.get(__response__, 'support_level'),
        vnis=pulumi.get(__response__, 'vnis')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetIdentityGroupResult',
    'AwaitableGetIdentityGroupResult',
    'get_identity_group',
    'get_identity_group_output',
]

@pulumi.output_type
class GetIdentityGroupResult:
    """
    A collection of values returned by getIdentityGroup.
    """
    def __init__(__self__, group_urn=None, creation=None, default_group=None, description=None, id=None, last_update=None, name=None, role=None):
        if group_urn and not isinstance(group_urn, str):
            raise TypeError("Expected argument 'group_urn' to be a str")
        pulumi.set(__self__, "group_urn", group_urn)
        if creation and not isinstance(creation, str):
            raise TypeError("Expected argument 'creation' to be a str")
        pulumi.set(__self__, "creation", creation)
        if default_group and not isinstance(default_group, bool):
            raise TypeError("Expected argument 'default_group' to be a bool")
        pulumi.set(__self__, "default_group", default_group)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if last_update and not isinstance(last_update, str):
            raise TypeError("Expected argument 'last_update' to be a str")
        pulumi.set(__self__, "last_update", last_update)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if role and not isinstance(role, str):
            raise TypeError("Expected argument 'role' to be a str")
        pulumi.set(__self__, "role", role)

    @property
    @pulumi.getter(name="GroupURN")
    def group_urn(self) -> builtins.str:
        """
        Identity URN of the group.
        """
        return pulumi.get(self, "group_urn")

    @property
    @pulumi.getter
    def creation(self) -> builtins.str:
        """
        Creation date of this group.
        """
        return pulumi.get(self, "creation")

    @property
    @pulumi.getter(name="defaultGroup")
    def default_group(self) -> builtins.bool:
        """
        Is the group a default and immutable one.
        """
        return pulumi.get(self, "default_group")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Group description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lastUpdate")
    def last_update(self) -> builtins.str:
        """
        Date of the last update of this group.
        """
        return pulumi.get(self, "last_update")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def role(self) -> builtins.str:
        """
        Role associated with the group. Valid roles are ADMIN, REGULAR, UNPRIVILEGED, and NONE.
        """
        return pulumi.get(self, "role")


class AwaitableGetIdentityGroupResult(GetIdentityGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIdentityGroupResult(
            group_urn=self.group_urn,
            creation=self.creation,
            default_group=self.default_group,
            description=self.description,
            id=self.id,
            last_update=self.last_update,
            name=self.name,
            role=self.role)


def get_identity_group(name: Optional[builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIdentityGroupResult:
    """
    Use this data source to retrieve information about an identity group.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_group = ovh.Me.get_identity_group(name="my_group_name")
    ```


    :param builtins.str name: Group name.
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Me/getIdentityGroup:getIdentityGroup', __args__, opts=opts, typ=GetIdentityGroupResult).value

    return AwaitableGetIdentityGroupResult(
        group_urn=pulumi.get(__ret__, 'group_urn'),
        creation=pulumi.get(__ret__, 'creation'),
        default_group=pulumi.get(__ret__, 'default_group'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        last_update=pulumi.get(__ret__, 'last_update'),
        name=pulumi.get(__ret__, 'name'),
        role=pulumi.get(__ret__, 'role'))
def get_identity_group_output(name: Optional[pulumi.Input[builtins.str]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetIdentityGroupResult]:
    """
    Use this data source to retrieve information about an identity group.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_group = ovh.Me.get_identity_group(name="my_group_name")
    ```


    :param builtins.str name: Group name.
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Me/getIdentityGroup:getIdentityGroup', __args__, opts=opts, typ=GetIdentityGroupResult)
    return __ret__.apply(lambda __response__: GetIdentityGroupResult(
        group_urn=pulumi.get(__response__, 'group_urn'),
        creation=pulumi.get(__response__, 'creation'),
        default_group=pulumi.get(__response__, 'default_group'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        last_update=pulumi.get(__response__, 'last_update'),
        name=pulumi.get(__response__, 'name'),
        role=pulumi.get(__response__, 'role')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetInstallationTemplateResult',
    'AwaitableGetInstallationTemplateResult',
    'get_installation_template',
    'get_installation_template_output',
]

@pulumi.output_type
class GetInstallationTemplateResult:
    """
    A collection of values returned by getInstallationTemplate.
    """
    def __init__(__self__, bit_format=None, category=None, description=None, distribution=None, end_of_install=None, family=None, filesystems=None, hard_raid_configuration=None, id=None, inputs=None, licenses=None, lvm_ready=None, no_partitioning=None, projects=None, soft_raid_only_mirroring=None, subfamily=None, template_name=None):
        if bit_format and not isinstance(bit_format, int):
            raise TypeError("Expected argument 'bit_format' to be a int")
        pulumi.set(__self__, "bit_format", bit_format)
        if category and not isinstance(category, str):
            raise TypeError("Expected argument 'category' to be a str")
        pulumi.set(__self__, "category", category)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if distribution and not isinstance(distribution, str):
            raise TypeError("Expected argument 'distribution' to be a str")
        pulumi.set(__self__, "distribution", distribution)
        if end_of_install and not isinstance(end_of_install, str):
            raise TypeError("Expected argument 'end_of_install' to be a str")
        pulumi.set(__self__, "end_of_install", end_of_install)
        if family and not isinstance(family, str):
            raise TypeError("Expected argument 'family' to be a str")
        pulumi.set(__self__, "family", family)
        if filesystems and not isinstance(filesystems, list):
            raise TypeError("Expected argument 'filesystems' to be a list")
        pulumi.set(__self__, "filesystems", filesystems)
        if hard_raid_configuration and not isinstance(hard_raid_configuration, bool):
            raise TypeError("Expected argument 'hard_raid_configuration' to be a bool")
        pulumi.set(__self__, "hard_raid_configuration", hard_raid_configuration)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if inputs and not isinstance(inputs, list):
            raise TypeError("Expected argument 'inputs' to be a list")
        pulumi.set(__self__, "inputs", inputs)
        if licenses and not isinstance(licenses, list):
            raise TypeError("Expected argument 'licenses' to be a list")
        pulumi.set(__self__, "licenses", licenses)
        if lvm_ready and not isinstance(lvm_ready, bool):
            raise TypeError("Expected argument 'lvm_ready' to be a bool")
        pulumi.set(__self__, "lvm_ready", lvm_ready)
        if no_partitioning and not isinstance(no_partitioning, bool):
            raise TypeError("Expected argument 'no_partitioning' to be a bool")
        pulumi.set(__self__, "no_partitioning", no_partitioning)
        if projects and not isinstance(projects, list):
            raise TypeError("Expected argument 'projects' to be a list")
        pulumi.set(__self__, "projects", projects)
        if soft_raid_only_mirroring and not isinstance(soft_raid_only_mirroring, bool):
            raise TypeError("Expected argument 'soft_raid_only_mirroring' to be a bool")
        pulumi.set(__self__, "soft_raid_only_mirroring", soft_raid_only_mirroring)
        if subfamily and not isinstance(subfamily, str):
            raise TypeError("Expected argument 'subfamily' to be a str")
        pulumi.set(__self__, "subfamily", subfamily)
        if template_name and not isinstance(template_name, str):
            raise TypeError("Expected argument 'template_name' to be a str")
        pulumi.set(__self__, "template_name", template_name)

    @property
    @pulumi.getter(name="bitFormat")
    def bit_format(self) -> builtins.int:
        """
        Template bit format (32 or 64).
        """
        return pulumi.get(self, "bit_format")

    @property
    @pulumi.getter
    def category(self) -> builtins.str:
        """
        Category of this template (informative only).
        """
        return pulumi.get(self, "category")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Information about this template.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def distribution(self) -> builtins.str:
        """
        Distribution this template is based on.
        """
        return pulumi.get(self, "distribution")

    @property
    @pulumi.getter(name="endOfInstall")
    def end_of_install(self) -> builtins.str:
        """
        End of install date of the template.
        """
        return pulumi.get(self, "end_of_install")

    @property
    @pulumi.getter
    def family(self) -> builtins.str:
        """
        Template family type.
        """
        return pulumi.get(self, "family")

    @property
    @pulumi.getter
    def filesystems(self) -> Sequence[builtins.str]:
        """
        Filesystems available.
        """
        return pulumi.get(self, "filesystems")

    @property
    @pulumi.getter(name="hardRaidConfiguration")
    def hard_raid_configuration(self) -> builtins.bool:
        return pulumi.get(self, "hard_raid_configuration")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def inputs(self) -> Sequence['outputs.GetInstallationTemplateInputResult']:
        """
        Represents the questions of the expected answers in the userMetadata field.
        """
        return pulumi.get(self, "inputs")

    @property
    @pulumi.getter
    def licenses(self) -> Sequence['outputs.GetInstallationTemplateLicenseResult']:
        """
        License available for this template.
        """
        return pulumi.get(self, "licenses")

    @property
    @pulumi.getter(name="lvmReady")
    def lvm_ready(self) -> builtins.bool:
        """
        Whether this template supports LVM.
        """
        return pulumi.get(self, "lvm_ready")

    @property
    @pulumi.getter(name="noPartitioning")
    def no_partitioning(self) -> builtins.bool:
        """
        Partitioning customization is not available for this OS template.
        """
        return pulumi.get(self, "no_partitioning")

    @property
    @pulumi.getter
    def projects(self) -> Sequence['outputs.GetInstallationTemplateProjectResult']:
        """
        Distribution project details.
        """
        return pulumi.get(self, "projects")

    @property
    @pulumi.getter(name="softRaidOnlyMirroring")
    def soft_raid_only_mirroring(self) -> builtins.bool:
        """
        Template supports RAID0 and RAID1 on 2 disks.
        """
        return pulumi.get(self, "soft_raid_only_mirroring")

    @property
    @pulumi.getter
    def subfamily(self) -> builtins.str:
        """
        Subfamily of the template.
        """
        return pulumi.get(self, "subfamily")

    @property
    @pulumi.getter(name="templateName")
    def template_name(self) -> builtins.str:
        return pulumi.get(self, "template_name")


class AwaitableGetInstallationTemplateResult(GetInstallationTemplateResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstallationTemplateResult(
            bit_format=self.bit_format,
            category=self.category,
            description=self.description,
            distribution=self.distribution,
            end_of_install=self.end_of_install,
            family=self.family,
            filesystems=self.filesystems,
            hard_raid_configuration=self.hard_raid_configuration,
            id=self.id,
            inputs=self.inputs,
            licenses=self.licenses,
            lvm_ready=self.lvm_ready,
            no_partitioning=self.no_partitioning,
            projects=self.projects,
            soft_raid_only_mirroring=self.soft_raid_only_mirroring,
            subfamily=self.subfamily,
            template_name=self.template_name)


def get_installation_template(template_name: Optional[builtins.str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstallationTemplateResult:
    """
    Use this data source to retrieve information about a specific OVH dedicated server installation template.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    ovh_template = ovh.get_installation_template(template_name="debian12_64")
    pulumi.export("template", ovh_template)
    ```


    :param builtins.str template_name: The name of the template.
    """
    __args__ = dict()
    __args__['templateName'] = template_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:index/getInstallationTemplate:getInstallationTemplate', __args__, opts=opts, typ=GetInstallationTemplateResult).value

    return AwaitableGetInstallationTemplateResult(
        bit_format=pulumi.get(__ret__, 'bit_format'),
        category=pulumi.get(__ret__, 'category'),
        description=pulumi.get(__ret__, 'description'),
        distribution=pulumi.get(__ret__, 'distribution'),
        end_of_install=pulumi.get(__ret__, 'end_of_install'),
        family=pulumi.get(__ret__, 'family'),
        filesystems=pulumi.get(__ret__, 'filesystems'),
        hard_raid_configuration=pulumi.get(__ret__, 'hard_raid_configuration'),
        id=pulumi.get(__ret__, 'id'),
        inputs=pulumi.get(__ret__, 'inputs'),
        licenses=pulumi.get(__ret__, 'licenses'),
        lvm_ready=pulumi.get(__ret__, 'lvm_ready'),
        no_partitioning=pulumi.get(__ret__, 'no_partitioning'),
        projects=pulumi.get(__ret__, 'projects'),
        soft_raid_only_mirroring=pulumi.get(__ret__, 'soft_raid_only_mirroring'),
        subfamily=pulumi.get(__ret__, 'subfamily'),
        template_name=pulumi.get(__ret__, 'template_name'))
def get_installation_template_output(template_name: Optional[pulumi.Input[builtins.str]] = None,
                                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInstallationTemplateResult]:
    """
    Use this data source to retrieve information about a specific OVH dedicated server installation template.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    ovh_template = ovh.get_installation_template(template_name="debian12_64")
    pulumi.export("template", ovh_template)
    ```


    :param builtins.str template_name: The name of the template.
    """
    __args__ = dict()
    __args__['templateName'] = template_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:index/getInstallationTemplate:getInstallationTemplate', __args__, opts=opts, typ=GetInstallationTemplateResult)
    return __ret__.apply(lambda __response__: GetInstallationTemplateResult(
        bit_format=pulumi.get(__response__, 'bit_format'),
        category=pulumi.get(__response__, 'category'),
        description=pulumi.get(__response__, 'description'),
        distribution=pulumi.get(__response__, 'distribution'),
        end_of_install=pulumi.get(__response__, 'end_of_install'),
        family=pulumi.get(__response__, 'family'),
        filesystems=pulumi.get(__response__, 'filesystems'),
        hard_raid_configuration=pulumi.get(__response__, 'hard_raid_configuration'),
        id=pulumi.get(__response__, 'id'),
        inputs=pulumi.get(__response__, 'inputs'),
        licenses=pulumi.get(__response__, 'licenses'),
        lvm_ready=pulumi.get(__response__, 'lvm_ready'),
        no_partitioning=pulumi.get(__response__, 'no_partitioning'),
        projects=pulumi.get(__response__, 'projects'),
        soft_raid_only_mirroring=pulumi.get(__response__, 'soft_raid_only_mirroring'),
        subfamily=pulumi.get(__response__, 'subfamily'),
        template_name=pulumi.get(__response__, 'template_name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['MoveArgs', 'Move']

@pulumi.input_type
class MoveArgs:
    def __init__(__self__, *,
                 ip: pulumi.Input[builtins.str],
                 routed_to: pulumi.Input['MoveRoutedToArgs'],
                 description: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Move resource.
        :param pulumi.Input[builtins.str] ip: IP block that we want to attach to a different service
        :param pulumi.Input['MoveRoutedToArgs'] routed_to: Service to route the IP to. If null, the IP will be [parked](https://api.ovh.com/console/#/ip/%7Bip%7D/park~POST) instead of [moved](https://api.ovh.com/console/#/ip/%7Bip%7D/move~POST)
        :param pulumi.Input[builtins.str] description: Description attached to the IP
        """
        pulumi.set(__self__, "ip", ip)
        pulumi.set(__self__, "routed_to", routed_to)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter
    def ip(self) -> pulumi.Input[builtins.str]:
        """
        IP block that we want to attach to a different service
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "ip", value)

    @property
    @pulumi.getter(name="routedTo")
    def routed_to(self) -> pulumi.Input['MoveRoutedToArgs']:
        """
        Service to route the IP to. If null, the IP will be [parked](https://api.ovh.com/console/#/ip/%7Bip%7D/park~POST) instead of [moved](https://api.ovh.com/console/#/ip/%7Bip%7D/move~POST)
        """
        return pulumi.get(self, "routed_to")

    @routed_to.setter
    def routed_to(self, value: pulumi.Input['MoveRoutedToArgs']):
        pulumi.set(self, "routed_to", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description attached to the IP
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _MoveState:
    def __init__(__self__, *,
                 can_be_terminated: Optional[pulumi.Input[builtins.bool]] = None,
                 country: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 organisation_id: Optional[pulumi.Input[builtins.str]] = None,
                 routed_to: Optional[pulumi.Input['MoveRoutedToArgs']] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 task_start_date: Optional[pulumi.Input[builtins.str]] = None,
                 task_status: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Move resources.
        :param pulumi.Input[builtins.bool] can_be_terminated: Whether IP service can be terminated
        :param pulumi.Input[builtins.str] country: Country
        :param pulumi.Input[builtins.str] description: Description attached to the IP
        :param pulumi.Input[builtins.str] ip: IP block that we want to attach to a different service
        :param pulumi.Input[builtins.str] organisation_id: IP block organisation Id
        :param pulumi.Input['MoveRoutedToArgs'] routed_to: Service to route the IP to. If null, the IP will be [parked](https://api.ovh.com/console/#/ip/%7Bip%7D/park~POST) instead of [moved](https://api.ovh.com/console/#/ip/%7Bip%7D/move~POST)
        :param pulumi.Input[builtins.str] service_name: Service name in the form of `ip-<part-1>.<part-2>.<part-3>.<part-4>`
        :param pulumi.Input[builtins.str] task_start_date: Starting date and time field of the current IP task that is in charge of changing the service the IP is attached to
        :param pulumi.Input[builtins.str] task_status: Status field of the current IP task that is in charge of changing the service the IP is attached to
        :param pulumi.Input[builtins.str] type: Possible values for ip type
        """
        if can_be_terminated is not None:
            pulumi.set(__self__, "can_be_terminated", can_be_terminated)
        if country is not None:
            pulumi.set(__self__, "country", country)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if organisation_id is not None:
            pulumi.set(__self__, "organisation_id", organisation_id)
        if routed_to is not None:
            pulumi.set(__self__, "routed_to", routed_to)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if task_start_date is not None:
            pulumi.set(__self__, "task_start_date", task_start_date)
        if task_status is not None:
            pulumi.set(__self__, "task_status", task_status)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="canBeTerminated")
    def can_be_terminated(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether IP service can be terminated
        """
        return pulumi.get(self, "can_be_terminated")

    @can_be_terminated.setter
    def can_be_terminated(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "can_be_terminated", value)

    @property
    @pulumi.getter
    def country(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Country
        """
        return pulumi.get(self, "country")

    @country.setter
    def country(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "country", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description attached to the IP
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IP block that we want to attach to a different service
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip", value)

    @property
    @pulumi.getter(name="organisationId")
    def organisation_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IP block organisation Id
        """
        return pulumi.get(self, "organisation_id")

    @organisation_id.setter
    def organisation_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "organisation_id", value)

    @property
    @pulumi.getter(name="routedTo")
    def routed_to(self) -> Optional[pulumi.Input['MoveRoutedToArgs']]:
        """
        Service to route the IP to. If null, the IP will be [parked](https://api.ovh.com/console/#/ip/%7Bip%7D/park~POST) instead of [moved](https://api.ovh.com/console/#/ip/%7Bip%7D/move~POST)
        """
        return pulumi.get(self, "routed_to")

    @routed_to.setter
    def routed_to(self, value: Optional[pulumi.Input['MoveRoutedToArgs']]):
        pulumi.set(self, "routed_to", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Service name in the form of `ip-<part-1>.<part-2>.<part-3>.<part-4>`
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="taskStartDate")
    def task_start_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Starting date and time field of the current IP task that is in charge of changing the service the IP is attached to
        """
        return pulumi.get(self, "task_start_date")

    @task_start_date.setter
    def task_start_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "task_start_date", value)

    @property
    @pulumi.getter(name="taskStatus")
    def task_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Status field of the current IP task that is in charge of changing the service the IP is attached to
        """
        return pulumi.get(self, "task_status")

    @task_status.setter
    def task_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "task_status", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Possible values for ip type
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("ovh:Ip/move:Move")
class Move(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 routed_to: Optional[pulumi.Input[Union['MoveRoutedToArgs', 'MoveRoutedToArgsDict']]] = None,
                 __props__=None):
        """
        Moves a given IP to a different service, or inversely, parks it if empty service is given

        ## Move IP `1.2.3.4` to service loadbalancer-XXXXX

        ```python
        import pulumi
        import pulumi_ovh as ovh

        move_ip_to_load_balancer_xxxxx = ovh.ip.Move("move_ip_to_load_balancer_xxxxx",
            ip="1.2.3.4",
            routed_to={
                "service_name": "loadbalancer-XXXXX",
            })
        ```

        ## Park IP/Detach IP `1.2.3.4` from any service

        ```python
        import pulumi
        import pulumi_ovh as ovh

        park_ip = ovh.ip.Move("park_ip",
            ip="1.2.3.4",
            routed_to={
                "service_name": "",
            })
        ```

        ## Import

        The resource can be imported using the `ip` field, e.g.,

        bash

        ```sh
        $ pulumi import ovh:Ip/move:Move mv '1.2.3.4/32'
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: Description attached to the IP
        :param pulumi.Input[builtins.str] ip: IP block that we want to attach to a different service
        :param pulumi.Input[Union['MoveRoutedToArgs', 'MoveRoutedToArgsDict']] routed_to: Service to route the IP to. If null, the IP will be [parked](https://api.ovh.com/console/#/ip/%7Bip%7D/park~POST) instead of [moved](https://api.ovh.com/console/#/ip/%7Bip%7D/move~POST)
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MoveArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Moves a given IP to a different service, or inversely, parks it if empty service is given

        ## Move IP `1.2.3.4` to service loadbalancer-XXXXX

        ```python
        import pulumi
        import pulumi_ovh as ovh

        move_ip_to_load_balancer_xxxxx = ovh.ip.Move("move_ip_to_load_balancer_xxxxx",
            ip="1.2.3.4",
            routed_to={
                "service_name": "loadbalancer-XXXXX",
            })
        ```

        ## Park IP/Detach IP `1.2.3.4` from any service

        ```python
        import pulumi
        import pulumi_ovh as ovh

        park_ip = ovh.ip.Move("park_ip",
            ip="1.2.3.4",
            routed_to={
                "service_name": "",
            })
        ```

        ## Import

        The resource can be imported using the `ip` field, e.g.,

        bash

        ```sh
        $ pulumi import ovh:Ip/move:Move mv '1.2.3.4/32'
        ```

        :param str resource_name: The name of the resource.
        :param MoveArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MoveArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 routed_to: Optional[pulumi.Input[Union['MoveRoutedToArgs', 'MoveRoutedToArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MoveArgs.__new__(MoveArgs)

            __props__.__dict__["description"] = description
            if ip is None and not opts.urn:
                raise TypeError("Missing required property 'ip'")
            __props__.__dict__["ip"] = ip
            if routed_to is None and not opts.urn:
                raise TypeError("Missing required property 'routed_to'")
            __props__.__dict__["routed_to"] = routed_to
            __props__.__dict__["can_be_terminated"] = None
            __props__.__dict__["country"] = None
            __props__.__dict__["organisation_id"] = None
            __props__.__dict__["service_name"] = None
            __props__.__dict__["task_start_date"] = None
            __props__.__dict__["task_status"] = None
            __props__.__dict__["type"] = None
        super(Move, __self__).__init__(
            'ovh:Ip/move:Move',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            can_be_terminated: Optional[pulumi.Input[builtins.bool]] = None,
            country: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            ip: Optional[pulumi.Input[builtins.str]] = None,
            organisation_id: Optional[pulumi.Input[builtins.str]] = None,
            routed_to: Optional[pulumi.Input[Union['MoveRoutedToArgs', 'MoveRoutedToArgsDict']]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            task_start_date: Optional[pulumi.Input[builtins.str]] = None,
            task_status: Optional[pulumi.Input[builtins.str]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None) -> 'Move':
        """
        Get an existing Move resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] can_be_terminated: Whether IP service can be terminated
        :param pulumi.Input[builtins.str] country: Country
        :param pulumi.Input[builtins.str] description: Description attached to the IP
        :param pulumi.Input[builtins.str] ip: IP block that we want to attach to a different service
        :param pulumi.Input[builtins.str] organisation_id: IP block organisation Id
        :param pulumi.Input[Union['MoveRoutedToArgs', 'MoveRoutedToArgsDict']] routed_to: Service to route the IP to. If null, the IP will be [parked](https://api.ovh.com/console/#/ip/%7Bip%7D/park~POST) instead of [moved](https://api.ovh.com/console/#/ip/%7Bip%7D/move~POST)
        :param pulumi.Input[builtins.str] service_name: Service name in the form of `ip-<part-1>.<part-2>.<part-3>.<part-4>`
        :param pulumi.Input[builtins.str] task_start_date: Starting date and time field of the current IP task that is in charge of changing the service the IP is attached to
        :param pulumi.Input[builtins.str] task_status: Status field of the current IP task that is in charge of changing the service the IP is attached to
        :param pulumi.Input[builtins.str] type: Possible values for ip type
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MoveState.__new__(_MoveState)

        __props__.__dict__["can_be_terminated"] = can_be_terminated
        __props__.__dict__["country"] = country
        __props__.__dict__["description"] = description
        __props__.__dict__["ip"] = ip
        __props__.__dict__["organisation_id"] = organisation_id
        __props__.__dict__["routed_to"] = routed_to
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["task_start_date"] = task_start_date
        __props__.__dict__["task_status"] = task_status
        __props__.__dict__["type"] = type
        return Move(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="canBeTerminated")
    def can_be_terminated(self) -> pulumi.Output[builtins.bool]:
        """
        Whether IP service can be terminated
        """
        return pulumi.get(self, "can_be_terminated")

    @property
    @pulumi.getter
    def country(self) -> pulumi.Output[builtins.str]:
        """
        Country
        """
        return pulumi.get(self, "country")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        Description attached to the IP
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def ip(self) -> pulumi.Output[builtins.str]:
        """
        IP block that we want to attach to a different service
        """
        return pulumi.get(self, "ip")

    @property
    @pulumi.getter(name="organisationId")
    def organisation_id(self) -> pulumi.Output[builtins.str]:
        """
        IP block organisation Id
        """
        return pulumi.get(self, "organisation_id")

    @property
    @pulumi.getter(name="routedTo")
    def routed_to(self) -> pulumi.Output['outputs.MoveRoutedTo']:
        """
        Service to route the IP to. If null, the IP will be [parked](https://api.ovh.com/console/#/ip/%7Bip%7D/park~POST) instead of [moved](https://api.ovh.com/console/#/ip/%7Bip%7D/move~POST)
        """
        return pulumi.get(self, "routed_to")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        Service name in the form of `ip-<part-1>.<part-2>.<part-3>.<part-4>`
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="taskStartDate")
    def task_start_date(self) -> pulumi.Output[builtins.str]:
        """
        Starting date and time field of the current IP task that is in charge of changing the service the IP is attached to
        """
        return pulumi.get(self, "task_start_date")

    @property
    @pulumi.getter(name="taskStatus")
    def task_status(self) -> pulumi.Output[builtins.str]:
        """
        Status field of the current IP task that is in charge of changing the service the IP is attached to
        """
        return pulumi.get(self, "task_status")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        Possible values for ip type
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['UserArgs', 'User']

@pulumi.input_type
class UserArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 openstack_rc: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 password_reset: Optional[pulumi.Input[builtins.str]] = None,
                 role_name: Optional[pulumi.Input[builtins.str]] = None,
                 role_names: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a User resource.
        :param pulumi.Input[builtins.str] description: A description associated with the user.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] openstack_rc: a convenient map representing an openstack_rc file. Note: no password nor sensitive token is set in this map.
        :param pulumi.Input[builtins.str] password_reset: Arbitrary string to change to trigger a password update
        :param pulumi.Input[builtins.str] role_name: The name of a role. See `role_names`.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] role_names: A list of role names. Values can be:
               - admin
               - administrator
               - ai_training_operator
               - ai_training_read
               - authentication
               - backup_operator
               - compute_operator
               - image_operator
               - infrastructure_supervisor
               - key-manager_operator
               - key-manager_read
               - load-balancer_operator
               - network_operator
               - network_security_operator
               - objectstore_operator
               - volume_operator
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if openstack_rc is not None:
            pulumi.set(__self__, "openstack_rc", openstack_rc)
        if password_reset is not None:
            pulumi.set(__self__, "password_reset", password_reset)
        if role_name is not None:
            pulumi.set(__self__, "role_name", role_name)
        if role_names is not None:
            pulumi.set(__self__, "role_names", role_names)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A description associated with the user.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="openstackRc")
    def openstack_rc(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        a convenient map representing an openstack_rc file. Note: no password nor sensitive token is set in this map.
        """
        return pulumi.get(self, "openstack_rc")

    @openstack_rc.setter
    def openstack_rc(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "openstack_rc", value)

    @property
    @pulumi.getter(name="passwordReset")
    def password_reset(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Arbitrary string to change to trigger a password update
        """
        return pulumi.get(self, "password_reset")

    @password_reset.setter
    def password_reset(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password_reset", value)

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of a role. See `role_names`.
        """
        return pulumi.get(self, "role_name")

    @role_name.setter
    def role_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "role_name", value)

    @property
    @pulumi.getter(name="roleNames")
    def role_names(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of role names. Values can be:
        - admin
        - administrator
        - ai_training_operator
        - ai_training_read
        - authentication
        - backup_operator
        - compute_operator
        - image_operator
        - infrastructure_supervisor
        - key-manager_operator
        - key-manager_read
        - load-balancer_operator
        - network_operator
        - network_security_operator
        - objectstore_operator
        - volume_operator
        """
        return pulumi.get(self, "role_names")

    @role_names.setter
    def role_names(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "role_names", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)


@pulumi.input_type
class _UserState:
    def __init__(__self__, *,
                 creation_date: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 openstack_rc: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 password_reset: Optional[pulumi.Input[builtins.str]] = None,
                 role_name: Optional[pulumi.Input[builtins.str]] = None,
                 role_names: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input['UserRoleArgs']]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering User resources.
        :param pulumi.Input[builtins.str] creation_date: the date the user was created.
        :param pulumi.Input[builtins.str] description: A description associated with the user.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] openstack_rc: a convenient map representing an openstack_rc file. Note: no password nor sensitive token is set in this map.
        :param pulumi.Input[builtins.str] password: (Sensitive) the password generated for the user. The password can be used with the Openstack API. This attribute is sensitive and will only be retrieve once during creation.
        :param pulumi.Input[builtins.str] password_reset: Arbitrary string to change to trigger a password update
        :param pulumi.Input[builtins.str] role_name: The name of a role. See `role_names`.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] role_names: A list of role names. Values can be:
               - admin
               - administrator
               - ai_training_operator
               - ai_training_read
               - authentication
               - backup_operator
               - compute_operator
               - image_operator
               - infrastructure_supervisor
               - key-manager_operator
               - key-manager_read
               - load-balancer_operator
               - network_operator
               - network_security_operator
               - objectstore_operator
               - volume_operator
        :param pulumi.Input[Sequence[pulumi.Input['UserRoleArgs']]] roles: A list of roles associated with the user.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] status: the status of the user. should be normally set to 'ok'.
        :param pulumi.Input[builtins.str] username: the username generated for the user. This username can be used with the Openstack API.
        """
        if creation_date is not None:
            pulumi.set(__self__, "creation_date", creation_date)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if openstack_rc is not None:
            pulumi.set(__self__, "openstack_rc", openstack_rc)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if password_reset is not None:
            pulumi.set(__self__, "password_reset", password_reset)
        if role_name is not None:
            pulumi.set(__self__, "role_name", role_name)
        if role_names is not None:
            pulumi.set(__self__, "role_names", role_names)
        if roles is not None:
            pulumi.set(__self__, "roles", roles)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter(name="creationDate")
    def creation_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        the date the user was created.
        """
        return pulumi.get(self, "creation_date")

    @creation_date.setter
    def creation_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "creation_date", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A description associated with the user.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="openstackRc")
    def openstack_rc(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        a convenient map representing an openstack_rc file. Note: no password nor sensitive token is set in this map.
        """
        return pulumi.get(self, "openstack_rc")

    @openstack_rc.setter
    def openstack_rc(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "openstack_rc", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        (Sensitive) the password generated for the user. The password can be used with the Openstack API. This attribute is sensitive and will only be retrieve once during creation.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="passwordReset")
    def password_reset(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Arbitrary string to change to trigger a password update
        """
        return pulumi.get(self, "password_reset")

    @password_reset.setter
    def password_reset(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password_reset", value)

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of a role. See `role_names`.
        """
        return pulumi.get(self, "role_name")

    @role_name.setter
    def role_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "role_name", value)

    @property
    @pulumi.getter(name="roleNames")
    def role_names(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of role names. Values can be:
        - admin
        - administrator
        - ai_training_operator
        - ai_training_read
        - authentication
        - backup_operator
        - compute_operator
        - image_operator
        - infrastructure_supervisor
        - key-manager_operator
        - key-manager_read
        - load-balancer_operator
        - network_operator
        - network_security_operator
        - objectstore_operator
        - volume_operator
        """
        return pulumi.get(self, "role_names")

    @role_names.setter
    def role_names(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "role_names", value)

    @property
    @pulumi.getter
    def roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['UserRoleArgs']]]]:
        """
        A list of roles associated with the user.
        """
        return pulumi.get(self, "roles")

    @roles.setter
    def roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['UserRoleArgs']]]]):
        pulumi.set(self, "roles", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        the status of the user. should be normally set to 'ok'.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        the username generated for the user. This username can be used with the Openstack API.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "username", value)


@pulumi.type_token("ovh:CloudProject/user:User")
class User(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 openstack_rc: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 password_reset: Optional[pulumi.Input[builtins.str]] = None,
                 role_name: Optional[pulumi.Input[builtins.str]] = None,
                 role_names: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Create a User resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: A description associated with the user.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] openstack_rc: a convenient map representing an openstack_rc file. Note: no password nor sensitive token is set in this map.
        :param pulumi.Input[builtins.str] password_reset: Arbitrary string to change to trigger a password update
        :param pulumi.Input[builtins.str] role_name: The name of a role. See `role_names`.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] role_names: A list of role names. Values can be:
               - admin
               - administrator
               - ai_training_operator
               - ai_training_read
               - authentication
               - backup_operator
               - compute_operator
               - image_operator
               - infrastructure_supervisor
               - key-manager_operator
               - key-manager_read
               - load-balancer_operator
               - network_operator
               - network_security_operator
               - objectstore_operator
               - volume_operator
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[UserArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a User resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param UserArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 openstack_rc: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 password_reset: Optional[pulumi.Input[builtins.str]] = None,
                 role_name: Optional[pulumi.Input[builtins.str]] = None,
                 role_names: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserArgs.__new__(UserArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["openstack_rc"] = openstack_rc
            __props__.__dict__["password_reset"] = password_reset
            __props__.__dict__["role_name"] = role_name
            __props__.__dict__["role_names"] = role_names
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["creation_date"] = None
            __props__.__dict__["password"] = None
            __props__.__dict__["roles"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["username"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(User, __self__).__init__(
            'ovh:CloudProject/user:User',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            creation_date: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            openstack_rc: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
            password: Optional[pulumi.Input[builtins.str]] = None,
            password_reset: Optional[pulumi.Input[builtins.str]] = None,
            role_name: Optional[pulumi.Input[builtins.str]] = None,
            role_names: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            roles: Optional[pulumi.Input[Sequence[pulumi.Input[Union['UserRoleArgs', 'UserRoleArgsDict']]]]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            username: Optional[pulumi.Input[builtins.str]] = None) -> 'User':
        """
        Get an existing User resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] creation_date: the date the user was created.
        :param pulumi.Input[builtins.str] description: A description associated with the user.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] openstack_rc: a convenient map representing an openstack_rc file. Note: no password nor sensitive token is set in this map.
        :param pulumi.Input[builtins.str] password: (Sensitive) the password generated for the user. The password can be used with the Openstack API. This attribute is sensitive and will only be retrieve once during creation.
        :param pulumi.Input[builtins.str] password_reset: Arbitrary string to change to trigger a password update
        :param pulumi.Input[builtins.str] role_name: The name of a role. See `role_names`.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] role_names: A list of role names. Values can be:
               - admin
               - administrator
               - ai_training_operator
               - ai_training_read
               - authentication
               - backup_operator
               - compute_operator
               - image_operator
               - infrastructure_supervisor
               - key-manager_operator
               - key-manager_read
               - load-balancer_operator
               - network_operator
               - network_security_operator
               - objectstore_operator
               - volume_operator
        :param pulumi.Input[Sequence[pulumi.Input[Union['UserRoleArgs', 'UserRoleArgsDict']]]] roles: A list of roles associated with the user.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] status: the status of the user. should be normally set to 'ok'.
        :param pulumi.Input[builtins.str] username: the username generated for the user. This username can be used with the Openstack API.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserState.__new__(_UserState)

        __props__.__dict__["creation_date"] = creation_date
        __props__.__dict__["description"] = description
        __props__.__dict__["openstack_rc"] = openstack_rc
        __props__.__dict__["password"] = password
        __props__.__dict__["password_reset"] = password_reset
        __props__.__dict__["role_name"] = role_name
        __props__.__dict__["role_names"] = role_names
        __props__.__dict__["roles"] = roles
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["status"] = status
        __props__.__dict__["username"] = username
        return User(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="creationDate")
    def creation_date(self) -> pulumi.Output[builtins.str]:
        """
        the date the user was created.
        """
        return pulumi.get(self, "creation_date")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        A description associated with the user.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="openstackRc")
    def openstack_rc(self) -> pulumi.Output[Mapping[str, builtins.str]]:
        """
        a convenient map representing an openstack_rc file. Note: no password nor sensitive token is set in this map.
        """
        return pulumi.get(self, "openstack_rc")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[builtins.str]:
        """
        (Sensitive) the password generated for the user. The password can be used with the Openstack API. This attribute is sensitive and will only be retrieve once during creation.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="passwordReset")
    def password_reset(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Arbitrary string to change to trigger a password update
        """
        return pulumi.get(self, "password_reset")

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The name of a role. See `role_names`.
        """
        return pulumi.get(self, "role_name")

    @property
    @pulumi.getter(name="roleNames")
    def role_names(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        A list of role names. Values can be:
        - admin
        - administrator
        - ai_training_operator
        - ai_training_read
        - authentication
        - backup_operator
        - compute_operator
        - image_operator
        - infrastructure_supervisor
        - key-manager_operator
        - key-manager_read
        - load-balancer_operator
        - network_operator
        - network_security_operator
        - objectstore_operator
        - volume_operator
        """
        return pulumi.get(self, "role_names")

    @property
    @pulumi.getter
    def roles(self) -> pulumi.Output[Sequence['outputs.UserRole']]:
        """
        A list of roles associated with the user.
        """
        return pulumi.get(self, "roles")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        the status of the user. should be normally set to 'ok'.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def username(self) -> pulumi.Output[builtins.str]:
        """
        the username generated for the user. This username can be used with the Openstack API.
        """
        return pulumi.get(self, "username")

